import { PeerId, Startable, TypedEventEmitter, PubSub } from "@libp2p/interface";
import { Registrar, ConnectionManager } from "@libp2p/interface-internal";
import type { Signature, Message, Signer } from "@canvas-js/interfaces";
import { AbstractGossipLog, GossipLogEvents } from "./AbstractGossipLog.js";
import { SyncOptions } from "./sync/service.js";
export type GossipLogServiceComponents = {
    peerId: PeerId;
    registrar: Registrar;
    connectionManager: ConnectionManager;
    pubsub?: PubSub;
};
export interface GossipLogServiceInit {
    sync?: boolean;
}
export declare class GossipLogService extends TypedEventEmitter<GossipLogEvents<unknown>> implements Startable {
    #private;
    private readonly components;
    private static extractGossipSub;
    static topicPrefix: "canvas/";
    private readonly sync;
    private readonly log;
    constructor(components: GossipLogServiceComponents, init: GossipLogServiceInit);
    isStarted(): boolean;
    start(): Promise<void>;
    afterStart(): Promise<void>;
    beforeStop(): Promise<void>;
    stop(): Promise<void>;
    subscribe<Payload>(messageLog: AbstractGossipLog<Payload>, options?: SyncOptions): Promise<void>;
    unsubscribe(topic: string): Promise<void>;
    private forwardEvent;
    append<Payload>(topic: string, payload: Payload, options?: {
        signer?: Pick<Signer<Payload>, "sign" | "verify">;
    }): Promise<{
        id: string;
        signature: Signature;
        message: Message<Payload>;
        recipients: Promise<PeerId[]>;
    }>;
    insert<Payload>(signature: Signature, message: Message<Payload>): Promise<{
        id: string;
        recipients: Promise<PeerId[]>;
    }>;
    getTopics(): string[];
    private handleMessage;
}
export declare const gossiplog: (init: GossipLogServiceInit) => (components: GossipLogServiceComponents) => GossipLogService;
